pub fn extract_global_config_args(matches: &ArgMatches) -> OverridableConfigExpand description
Extract config arguments from the global command line arguments.
pub fn extract_global_config_args(matches: &ArgMatches) -> OverridableConfigExtract config arguments from the global command line arguments.